@@ -13,7 +13,7 @@ use Imager;
 use List::MoreUtils qw(none);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -380,7 +380,17 @@ L<List::MoreUtils>.
 
 =head1 SEE ALSO
 
-L<Image::Random>.
+=over
+
+=item L<Image::Random>
+
+Perl class for creating random image.
+
+=back
+
+=head1 REPOSITORY
+
+L<https://github.com/tupinek/Image-Select>
 
 =head1 AUTHOR
 
@@ -390,10 +400,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2014-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
